////////////////////////////////////////////////////////////////////////////////
//
// Fracter - A simple Mandelbrot Set viewer.
//
// Copyright (C) 2010 Sarah Eris Horsley Caffee
//
// This file is part of Fracter.
//
// Fracter is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
//
// EventHandler.cpp
// EventHandler class implementation.
//
////////////////////////////////////////////////////////////////////////////////

#include "EventHandler.h"


////////////////////////////////////////////////////////////////////////////////
EventHandler::EventHandler()
   {
   }


////////////////////////////////////////////////////////////////////////////////
EventHandler::~EventHandler()
   {
   }


////////////////////////////////////////////////////////////////////////////////
void EventHandler::on_Event(SDL_Event * event)
   {
   switch(event->type)
      {
      case SDL_ACTIVEEVENT: 
	 {
	 switch(event->active.state)
	    {	   
	    case SDL_APPMOUSEFOCUS:
	       {
	       if (event->active.gain) on_MouseFocus();
	       else on_MouseBlur();
	       break;
	       }
	    case SDL_APPINPUTFOCUS:
	       {
	       if (event->active.gain) on_InputFocus();
	       else on_InputBlur();
	       break;
	       }
	    case SDL_APPACTIVE:
	       {
	       if (event->active.gain) on_Restore();
	       else on_Minimize();
	       break;
	       }
	    }
	 break;
	 }

      case SDL_KEYDOWN:
	 {
	 on_KeyDown(event->key);
	 break;
	 }
      case SDL_KEYUP:
	 {
	 on_KeyUp(event->key);
	 break;
	 }

      case SDL_MOUSEMOTION: 
	 {
	 on_MouseMove(event->motion);
	 break;
	 }
      case SDL_MOUSEBUTTONDOWN:
	 {
	 switch (event->button.button)
	    {
	    case SDL_BUTTON_LEFT:
	       {
	       on_LButtonDown(event->button);
	       break;
	       }
	    case SDL_BUTTON_RIGHT:
	       {
	       on_RButtonDown(event->button);
	       break;
	       }
	    case SDL_BUTTON_MIDDLE:
	       {
	       on_MButtonDown(event->button);
	       break;
	       }
	    case SDL_BUTTON_WHEELDOWN:
	       {
	       on_MouseWheelDown(event->button);
	       break;
	       }
	    }
	 break;
	 }
      case SDL_MOUSEBUTTONUP:
	 {
	 switch (event->button.button)
	    {
	    case SDL_BUTTON_LEFT:
	       {
	       on_LButtonUp(event->button);
	       break;
	       }
	    case SDL_BUTTON_RIGHT:
	       {
	       on_RButtonUp(event->button);
	       break;
	       }
	    case SDL_BUTTON_MIDDLE:
	       {
	       on_MButtonUp(event->button);
	       break;
	       }
	    case SDL_BUTTON_WHEELUP:
	       {
	       on_MouseWheelUp(event->button);
	       break;
	       }
	    }
	 break;
	 }

      case SDL_JOYAXISMOTION:
	 {
	 on_JoyAxis(event->jaxis);
	 break;
	 }
      case SDL_JOYBALLMOTION:
	 {
	 on_JoyBall(event->jball);
	 break;
	 }
      case SDL_JOYHATMOTION:
	 {
	 on_JoyHat(event->jhat);
	 break;
	 }
      case SDL_JOYBUTTONDOWN:
	 {
	 on_JoyButtonDown(event->jbutton);
	 break;
	 }
      case SDL_JOYBUTTONUP:
	 {
	 on_JoyButtonUp(event->jbutton);
	 break;
	 }

      case SDL_VIDEORESIZE:
	 {
	 on_Resize(event->resize);
	 break;
	 }
      case SDL_VIDEOEXPOSE:
	 {
	 on_Expose();
	 break;
	 }
      case SDL_QUIT:
	 {
	 on_Quit();
	 break;
	 }
      case SDL_SYSWMEVENT:
	 {
	 on_SysWM(event->syswm);
	 break;
	 }

      case SDL_NOEVENT:
      case SDL_EVENT_RESERVEDA:
      case SDL_EVENT_RESERVEDB:
      case SDL_EVENT_RESERVED2:
      case SDL_EVENT_RESERVED3:
      case SDL_EVENT_RESERVED4:
      case SDL_EVENT_RESERVED5:
      case SDL_EVENT_RESERVED6:
      case SDL_EVENT_RESERVED7:
      case SDL_NUMEVENTS:
	 {
	 // Reserved events are silently ignored.
	 break;
	 }

      default:
	 {
	 // All other events are user events.
	 on_User(event->user);
	 break;
	 }
      }
   }



////////////////////////////////////////////////////////////////////////////////

// Active events

void EventHandler::on_MouseFocus()
   {
   }

void EventHandler::on_MouseBlur()
   {
   }

void EventHandler::on_InputFocus()
   {
   }

void EventHandler::on_InputBlur()
   {
   }

void EventHandler::on_Minimize()
   {
   }

void EventHandler::on_Restore()
   {
   }


// Keyboard events

void EventHandler::on_KeyDown(SDL_KeyboardEvent key)
   {
   }

void EventHandler::on_KeyUp(SDL_KeyboardEvent key)
   {
   }


// Mouse events

void EventHandler::on_MouseMove(SDL_MouseMotionEvent motion)
   {
   }

void EventHandler::on_LButtonDown(SDL_MouseButtonEvent button)
   {
   }

void EventHandler::on_LButtonUp(SDL_MouseButtonEvent button)
   {
   }

void EventHandler::on_RButtonDown(SDL_MouseButtonEvent button)
   {
   }

void EventHandler::on_RButtonUp(SDL_MouseButtonEvent button)
   {
   }

void EventHandler::on_MButtonDown(SDL_MouseButtonEvent button)
   {
   }

void EventHandler::on_MButtonUp(SDL_MouseButtonEvent button)
   {
   }

void EventHandler::on_MouseWheelDown(SDL_MouseButtonEvent button)
   {
   }

void EventHandler::on_MouseWheelUp(SDL_MouseButtonEvent button)
   {
   }


// Joystick events

void EventHandler::on_JoyAxis(SDL_JoyAxisEvent jaxis)
   {
   }

void EventHandler::on_JoyButtonDown(SDL_JoyButtonEvent jbutton)
   {
   }

void EventHandler::on_JoyButtonUp(SDL_JoyButtonEvent jbutton)
   {
   }

void EventHandler::on_JoyHat(SDL_JoyHatEvent jhat)
   {
   }

void EventHandler::on_JoyBall(SDL_JoyBallEvent jball)
   {
   }


// Misc events

void EventHandler::on_Resize(SDL_ResizeEvent resize)
   {
   }

void EventHandler::on_Expose()
   {
   }

void EventHandler::on_Quit()
   {
   }

void EventHandler::on_User(SDL_UserEvent user)
   {
   }

void EventHandler::on_SysWM(SDL_SysWMEvent syswm)
   {
   }
